Class: Alchemy::Admin::PagesController

Inherits:
ResourcesController show all
Includes:
CurrentLanguage, OnPageLayout::CallbacksRunner
Defined in:
app/controllers/alchemy/admin/pages_controller.rb

Constant Summary

Constants included from ResourceFilter

ResourceFilter::COMMON_SEARCH_FILTER_EXCLUDES

Instance Method Summary collapse

Methods included from ResourceName

#controller_path_array, #resource_array, #resource_model_name, #resource_name, #resources_name

Methods included from ResourcesHelper

#contains_relations?, #edit_resource_path, #new_resource_path, #render_attribute, #resource_attribute_field_options, #resource_has_tags, #resource_instance_variable, #resource_model, #resource_path, #resource_relations_names, #resource_scope, #resource_url_proxy, #resource_window_size, #resources_instance_variable, #resources_path

Methods inherited from BaseController

#leave

Methods included from Modules

included, #module_definition_for, register_module

Methods included from Alchemy::AbilityHelper

#current_ability

Methods included from ConfigurationMethods

#configuration, #multi_language?, #multi_site?, #prefix_locale?

Instance Method Details

#configureObject

Set page configuration like page names, meta tags and states.



131
132
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 131

def configure
end

#copy_language_treeObject



213
214
215
216
217
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 213

def copy_language_tree
  language_root_to_copy_from.copy_children_to(copy_of_language_root)
  flash[:notice] = Alchemy.t(:language_pages_copied)
  redirect_to admin_pages_path
end

#createObject



96
97
98
99
100
101
102
103
104
105
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 96

def create
  @page = paste_from_clipboard || Page.new(page_params)
  if @page.save
    flash[:notice] = Alchemy.t("Page created", name: @page.name)
    do_redirect_to(redirect_path_after_create_page)
  else
    new
    render :new
  end
end

#destroyObject

Fetches page via before filter, destroys it and redirects to page tree



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 157

def destroy
  if @page.destroy
    flash[:notice] = Alchemy.t("Page deleted", name: @page.name)

    # Remove page from clipboard
    clipboard = get_clipboard("pages")
    clipboard.delete_if { |item| item["id"] == @page.id.to_s }
  else
    flash[:warning] = @page.errors.full_messages.to_sentence
  end

  if @page.layoutpage?
    redirect_to alchemy.admin_layoutpages_path
  else
    redirect_to alchemy.admin_pages_path
  end
end

#editObject

Edit the content of the page and all its elements and ingredients.

Locks the page to current user to prevent other users from editing it meanwhile.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 111

def edit
  # fetching page via before filter
  if page_is_locked?
    flash[:warning] = Alchemy.t("This page is locked", name: @page.locker_name)
    redirect_to admin_pages_path
  elsif page_needs_lock?
    @page.lock_to!(current_alchemy_user)
  end
  @preview_urls = Alchemy.config.preview_sources.map do |klass|
    [
      klass.model_name.human,
      klass.new(routes: Alchemy::Engine.routes).url_for(@page)
    ]
  end
  @preview_url = @preview_urls.first.last
  @layoutpage = @page.layoutpage?
  Alchemy::Current.language = @page.language
end

#flushObject



219
220
221
222
223
224
225
226
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 219

def flush
  @current_language.pages.flushables.update_all(published_at: Time.current)
  # We need to ensure, that also all layoutpages get the +published_at+ timestamp set,
  # but not set to public true, because the cache_key for an element is +published_at+
  # and we don't want the layout pages to be present in +Page.published+ scope.
  @current_language.pages.flushable_layoutpages.update_all(published_at: Time.current)
  respond_to { |format| format.js }
end

#foldObject



179
180
181
182
183
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 179

def fold
  # @page is fetched via before filter
  @page.fold!(current_alchemy_user.id, !@page.folded?(current_alchemy_user.id))
  render json: serialized_page_tree
end

#indexObject



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 52

def index
  @query = @current_language.pages.contentpages.ransack(search_filter_params[:q])

  if @view == "list"
    @query.sorts = default_sort_order if @query.sorts.empty?
    items = @query.result

    if search_filter_params[:tagged_with].present?
      items = items.tagged_with(search_filter_params[:tagged_with])
    end

    items = items.page(params[:page] || 1).per(items_per_page)
    @pages = items
  end
end

#infoObject



85
86
87
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 85

def info
  render layout: !request.xhr?
end


175
176
177
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 175

def link
  render LinkDialog::Tabs.new(**link_dialog_params)
end

#newObject



89
90
91
92
93
94
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 89

def new
  @page ||= Page.new(layoutpage: params[:layoutpage] == "true", parent_id: params[:parent_id])
  @page_layouts = Page.layouts_for_select(@current_language.id, layoutpages: @page.layoutpage?)
  @clipboard = get_clipboard("pages")
  @clipboard_items = Page.all_from_clipboard_for_select(@clipboard, @current_language.id, layoutpages: @page.layoutpage?)
end

#publishObject

Sets the page public and updates the published_at attribute that is used as cache_key



205
206
207
208
209
210
211
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 205

def publish
  # fetching page via before filter
  @page.publish!

  flash[:notice] = Alchemy.t(:page_published, name: @page.name)
  redirect_back(fallback_location: admin_pages_path)
end

#showObject

Used by page preview iframe in Page#edit view.



76
77
78
79
80
81
82
83
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 76

def show
  authorize! :edit_content, @page

  Current.preview_page = @page
  # Setting the locale to pages language, so the page content has it's correct translations.
  ::I18n.locale = @page.language.locale
  render(layout: Alchemy.config.admin_page_preview_layout || "application")
end

#treeObject

Returns all pages as a tree from the root given by the id parameter



70
71
72
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 70

def tree
  render json: serialized_page_tree
end

#unlockObject

Leaves the page editing mode and unlocks the page for other users



186
187
188
189
190
191
192
193
194
195
196
197
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 186

def unlock
  # fetching page via before filter
  @page.unlock!
  flash[:notice] = Alchemy.t(:unlocked_page, name: @page.name)
  @pages_locked_by_user = Page.from_current_site.locked_by(current_alchemy_user)
  respond_to do |format|
    format.js
    format.html do
      redirect_to(unlock_redirect_path, allow_other_host: true)
    end
  end
end

#unlock_redirect_pathObject



199
200
201
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 199

def unlock_redirect_path
  safe_redirect_path(fallback: admin_pages_path)
end

#updateObject

Updates page

  • fetches page via before filter



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'app/controllers/alchemy/admin/pages_controller.rb', line 138

def update
  @old_parent_id = @page.parent_id
  if @page.update(page_params)
    @notice = Alchemy.t("Page saved", name: @page.name)
    @while_page_edit = request.referer.include?("edit")

    if @view == "list"
      flash[:notice] = @notice
    end

    unless @while_page_edit
      @tree = serialized_page_tree
    end
  else
    render :configure, status: :unprocessable_entity
  end
end